@@ -56,7 +56,9 @@ use_precommit_config <- function(config_source = getOption("precommit.config_sou
   }
 
   if (is_package(root)) {
-    usethis::write_union(".Rbuildignore", escaped_name_target)
+    usethis::with_project(root, {
+      usethis::write_union(fs::path(root, ".Rbuildignore"), escaped_name_target)
+    })
   }
   usethis::ui_todo(c(
     "Edit .precommit-hooks.yaml to (de)activate the hooks you want to use. ",
